local E, L, V, P, G = unpack(ElvUI)
local IsAddOnLoaded = IsAddOnLoaded
local format = string.format
local MyPluginName = "GennUI"
local GNUI = E:GetModule("GennUI");

--[[ Setup Chat ]]--
function GNUI:SetupChat()
	
	FCF_ResetChatWindows()
	FCF_SetLocked(ChatFrame1, 1)
	FCF_DockFrame(ChatFrame1)
	FCF_SetLocked(ChatFrame2, 1)
	FCF_OpenNewWindow(TRADE)
	FCF_SetLocked(ChatFrame3, 1)
	FCF_DockFrame(ChatFrame3)
	
	for i = 1, NUM_CHAT_WINDOWS do
		local frame = _G[format('ChatFrame%s', i)]

		FCF_SavePositionAndDimensions(frame)
		FCF_StopDragging(frame)

		FCF_SetChatWindowFontSize(nil, frame, 12)

		if i == 1 then
			FCF_SetWindowName(frame, GENERAL)
		elseif i == 2 then
			FCF_SetWindowName(frame, GUILD_EVENT_LOG)
		elseif i == 3 then
			FCF_SetWindowName(frame, TRADE)
		end
	end
	
	-- keys taken from `ChatTypeGroup` but doesnt add: 'OPENING', 'TRADESKILLS', 'PET_INFO', 'COMBAT_MISC_INFO', 'COMMUNITIES_CHANNEL', 'PET_BATTLE_COMBAT_LOG', 'PET_BATTLE_INFO', 'TARGETICONS'
	local chatGroup = { 'SYSTEM', 'CHANNEL', 'SAY', 'EMOTE', 'YELL', 'WHISPER', 'PARTY', 'PARTY_LEADER', 'RAID', 'RAID_LEADER', 'RAID_WARNING', 'INSTANCE_CHAT', 'INSTANCE_CHAT_LEADER', 'GUILD', 'OFFICER', 'MONSTER_SAY', 'MONSTER_YELL', 'MONSTER_EMOTE', 'MONSTER_WHISPER', 'MONSTER_BOSS_EMOTE', 'MONSTER_BOSS_WHISPER', 'ERRORS', 'AFK', 'DND', 'IGNORED', 'BG_HORDE', 'BG_ALLIANCE', 'BG_NEUTRAL', 'ACHIEVEMENT', 'GUILD_ACHIEVEMENT', 'BN_WHISPER', 'BN_INLINE_TOAST_ALERT', 'COMBAT_XP_GAIN', 'COMBAT_HONOR_GAIN', 'COMBAT_FACTION_CHANGE', 'SKILL', 'LOOT', 'CURRENCY', 'MONEY' }
	ChatFrame_RemoveAllMessageGroups(_G.ChatFrame1)
	ChatFrame_RemoveAllMessageGroups(_G.ChatFrame3)
	for _, v in ipairs(chatGroup) do
		ChatFrame_AddMessageGroup(_G.ChatFrame1, v)
	end

	ChatFrame_AddChannel(_G.ChatFrame1, GENERAL)
	ChatFrame_RemoveChannel(_G.ChatFrame1, TRADE)
	ChatFrame_AddChannel(_G.ChatFrame3, TRADE)

	-- set the chat groups names in class color to enabled for all chat groups which players names appear
	chatGroup = { 'SAY', 'EMOTE', 'YELL', 'WHISPER', 'PARTY', 'PARTY_LEADER', 'RAID', 'RAID_LEADER', 'RAID_WARNING', 'INSTANCE_CHAT', 'INSTANCE_CHAT_LEADER', 'GUILD', 'OFFICER', 'ACHIEVEMENT', 'GUILD_ACHIEVEMENT', 'COMMUNITIES_CHANNEL', 'CHANNEL1', 'CHANNEL2', 'CHANNEL3', 'CHANNEL4', 'CHANNEL5', 'CHANNEL6', 'CHANNEL7', 'CHANNEL8', 'CHANNEL9', 'CHANNEL10', 'CHANNEL11' }
	for i = 1, _G.MAX_WOW_CHAT_CHANNELS do
		tinsert(chatGroup, 'CHANNEL'..i)
	end
	for _, v in ipairs(chatGroup) do
		ToggleChatColorNamesByClassGroup(true, v)
	end
		
	E:Print(L["Chat has been set"])
	PluginInstallStepComplete.message = "Chat has been set"
	PluginInstallStepComplete:Show()
end

--[[ Class Colors ]]--
local colorTable = class == 'PRIEST' and E.PriestColors or (_G.CUSTOM_CLASS_COLORS and _G.CUSTOM_CLASS_COLORS[class] or _G.RAID_CLASS_COLORS[class])
local classColor = RAID_CLASS_COLORS[E.myclass]

--[[ Layout Settings ]]--
function GNUI:SetupLayout(layout)

-- Movers
E.db["movers"] = E.db["movers"] or {}
E.db["movers"]["AlertFrameMover"] = "TOP,ElvUIParent,TOP,0,-157"
E.db["movers"]["AltPowerBarMover"] = "TOP,ElvUIParent,TOP,0,-239"
E.db["movers"]["ArenaHeaderMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-430,480"
E.db["movers"]["AzeriteBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-196"
E.db["movers"]["BNETMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,327"
E.db["movers"]["BelowMinimapContainerMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-460,-260"
E.db["movers"]["BossButton"] = "BOTTOM,ElvUIParent,BOTTOM,-320,150"
E.db["movers"]["BossHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-220,-466"
E.db["movers"]["DurabilityFrameMover"] = "TOP,ElvUIParent,TOP,320,-177"
E.db["movers"]["ElvAB_1"] = "BOTTOM,ElvUIParent,BOTTOM,0,12"
E.db["movers"]["ElvAB_2"] = "BOTTOM,ElvUIParent,BOTTOM,0,50"
E.db["movers"]["ElvAB_3"] = "BOTTOM,ElvUIParent,BOTTOM,327,12"
E.db["movers"]["ElvAB_5"] = "BOTTOM,ElvUIParent,BOTTOM,-327,12"
E.db["movers"]["ElvUF_AssistMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,4,-280"
E.db["movers"]["ElvUF_FocusCastbarMover"] = "TOP,ElvUIParent,TOP,0,-457"
E.db["movers"]["ElvUF_FocusMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-614,-400"
E.db["movers"]["ElvUF_PartyMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,430,480"
E.db["movers"]["ElvUF_PetMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,614,280"
E.db["movers"]["ElvUF_PlayerCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,456"
E.db["movers"]["ElvUF_PlayerMover"] = "BOTTOM,ElvUIParent,BOTTOM,-342,344"
E.db["movers"]["ElvUF_Raid40Mover"] = "BOTTOM,ElvUIParent,BOTTOM,0,91"
E.db["movers"]["ElvUF_RaidMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,93"
E.db["movers"]["ElvUF_TargetCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,476"
E.db["movers"]["ElvUF_TargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,342,344"
E.db["movers"]["ElvUF_TargetTargetMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-614,280"
E.db["movers"]["ExperienceBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-172"
E.db["movers"]["HonorBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-188"
E.db["movers"]["LevelUpBossBannerMover"] = "TOP,ElvUIParent,TOP,0,-199"
E.db["movers"]["MicrobarMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-335,4"
E.db["movers"]["MinimapMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-3,-3"
E.db["movers"]["PetAB"] = "BOTTOM,ElvUIParent,BOTTOM,-342,320"
E.db["movers"]["ReputationBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-180"
E.db["movers"]["ShiftAB"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-484,32"
E.db["movers"]["TalkingHeadFrameMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,209"
E.db["movers"]["ThreatBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,4"
E.db["movers"]["TotemBarMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,432,4"
E.db["movers"]["VOICECHAT"] = "TOPLEFT,ElvUIParent,TOPLEFT,4,-590"
E.db["movers"]["VehicleLeaveButton"] = "TOP,ElvUIParent,TOP,0,-505"
E.db["movers"]["VehicleSeatMover"] = "TOP,ElvUIParent,TOP,322,-4"
E.db["movers"]["ZoneAbility"] = "BOTTOM,ElvUIParent,BOTTOM,320,150"

-- DataBars
E.db["databars"]["colors"]["experience"]["a"] = 1
E.db["databars"]["colors"]["experience"]["b"] = classColor.b
E.db["databars"]["colors"]["experience"]["g"] = classColor.g
E.db["databars"]["colors"]["experience"]["r"] = classColor.r
E.db["databars"]["colors"]["quest"]["a"] = 0.40
E.db["databars"]["colors"]["quest"]["b"] = classColor.b
E.db["databars"]["colors"]["quest"]["g"] = classColor.g
E.db["databars"]["colors"]["quest"]["r"] = classColor.r
E.db["databars"]["colors"]["rested"]["a"] = 0.40
E.db["databars"]["colors"]["rested"]["b"] = classColor.b
E.db["databars"]["colors"]["rested"]["g"] = classColor.g
E.db["databars"]["colors"]["rested"]["r"] = classColor.r
E.db["databars"]["experience"]["font"] = "Exo 2 Semi Bold"
E.db["databars"]["experience"]["fontSize"] = 11
E.db["databars"]["experience"]["height"] = 6
E.db["databars"]["experience"]["hideAtMaxLevel"] = false
E.db["databars"]["experience"]["width"] = 150
E.db["databars"]["reputation"]["enable"] = true
E.db["databars"]["reputation"]["font"] = "Exo 2 Semi Bold"
E.db["databars"]["reputation"]["height"] = 6
E.db["databars"]["reputation"]["mouseover"] = true
E.db["databars"]["reputation"]["width"] = 150
E.db["databars"]["threat"]["font"] = "Exo 2 Semi Bold"
E.db["databars"]["threat"]["height"] = 6
E.db["databars"]["threat"]["mouseover"] = true
E.db["databars"]["threat"]["width"] = 454

-- Tooltip
E.db["tooltip"]["cursorAnchor"] = true
E.db["tooltip"]["font"] = "Exo 2 Semi Bold"
E.db["tooltip"]["fontOutline"] = "OUTLINE"
E.db["tooltip"]["headerFontSize"] = 11
E.db["tooltip"]["healthBar"]["font"] = "Exo 2 Semi Bold"
E.db["tooltip"]["healthBar"]["fontSize"] = 12
E.db["tooltip"]["healthBar"]["height"] = 1
E.db["tooltip"]["healthBar"]["statusPosition"] = "TOP"
E.db["tooltip"]["itemCount"] = "BOTH"
E.db["tooltip"]["role"] = false
E.db["tooltip"]["showMount"] = false
E.db["tooltip"]["smallTextFontSize"] = 11
E.db["tooltip"]["textFontSize"] = 11

-- Bags
E.db["bags"]["bagBar"]["spacing"] = 1
E.db["bags"]["bagSize"] = 28
E.db["bags"]["bankSize"] = 28
E.db["bags"]["clearSearchOnClose"] = true
E.db["bags"]["countFont"] = "Exo 2 Semi Bold"
E.db["bags"]["countFontOutline"] = "OUTLINE"
E.db["bags"]["countFontSize"] = 11
E.db["bags"]["disableBagSort"] = true
E.db["bags"]["disableBankSort"] = true
E.db["bags"]["itemLevelFont"] = "Exo 2 Semi Bold"
E.db["bags"]["itemLevelFontOutline"] = "OUTLINE"
E.db["bags"]["itemLevelFontSize"] = 11
E.db["bags"]["junkDesaturate"] = true
E.db["bags"]["junkIcon"] = true
E.db["bags"]["moneyCoins"] = false
E.db["bags"]["moneyFormat"] = "BLIZZARD"
E.db["bags"]["showBindType"] = true
E.db["bags"]["vendorGrays"]["enable"] = true

-- Chat
E.db["chat"]["chatHistory"] = false
E.db["chat"]["emotionIcons"] = false
E.db["chat"]["font"] = "Exo 2 Semi Bold"
E.db["chat"]["fontOutline"] = "OUTLINE"
E.db["chat"]["fontSize"] = 12
E.db["chat"]["panelBackdrop"] = "HIDEBOTH"
E.db["chat"]["panelWidth"] = 426
E.db["chat"]["tabFont"] = "Exo 2 Semi Bold"
E.db["chat"]["tabFontOutline"] = "OUTLINE"
E.db["chat"]["tabFontSize"] = 12

-- Auras
E.db["auras"]["cooldown"]["override"] = true
E.db["auras"]["buffs"]["barColor"]["b"] = classColor.b
E.db["auras"]["buffs"]["barColor"]["g"] = classColor.g
E.db["auras"]["buffs"]["barColor"]["r"] = classColor.r
E.db["auras"]["buffs"]["barSpacing"] = 0
E.db["auras"]["buffs"]["barTexture"] = "GennUI Blinkii"
E.db["auras"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["auras"]["buffs"]["countFontOutline"] = "OUTLINE"
E.db["auras"]["buffs"]["countFontSize"] = 11
E.db["auras"]["buffs"]["horizontalSpacing"] = 2
E.db["auras"]["buffs"]["size"] = 30
E.db["auras"]["buffs"]["timeFont"] = "Exo 2 Semi Bold"
E.db["auras"]["buffs"]["timeFontOutline"] = "OUTLINE"
E.db["auras"]["buffs"]["timeFontSize"] = 11
E.db["auras"]["buffs"]["timeYOffset"] = 6
E.db["auras"]["debuffs"]["barColor"]["b"] = classColor.b
E.db["auras"]["debuffs"]["barColor"]["g"] = classColor.g
E.db["auras"]["debuffs"]["barColor"]["r"] = classColor.r
E.db["auras"]["debuffs"]["barSpacing"] = 1
E.db["auras"]["debuffs"]["barTexture"] = "GennUI Blinkii"
E.db["auras"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["auras"]["debuffs"]["countFontOutline"] = "OUTLINE"
E.db["auras"]["debuffs"]["countFontSize"] = 11
E.db["auras"]["debuffs"]["horizontalSpacing"] = 2
E.db["auras"]["debuffs"]["size"] = 30
E.db["auras"]["debuffs"]["timeFont"] = "Exo 2 Semi Bold"
E.db["auras"]["debuffs"]["timeFontOutline"] = "OUTLINE"
E.db["auras"]["debuffs"]["timeFontSize"] = 11
E.db["auras"]["debuffs"]["timeYOffset"] = 6

-- Unitframes
---> UF Colors & Stuff
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][1]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][2]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["comboPoints"][3]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["DEATHKNIGHT"]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["DEATHKNIGHT"]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["DEATHKNIGHT"]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["PALADIN"]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["PALADIN"]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["PALADIN"]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MAGE"]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MAGE"]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MAGE"]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["WARLOCK"]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][1]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][1]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][1]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][2]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][2]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][2]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][3]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][3]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][3]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][4]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][4]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][4]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][5]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][5]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][5]["b"] = classColor.b
E.db["unitframe"]["colors"]["classResources"]["MONK"][6]["r"] = classColor.r
E.db["unitframe"]["colors"]["classResources"]["MONK"][6]["g"] = classColor.g
E.db["unitframe"]["colors"]["classResources"]["MONK"][6]["b"] = classColor.b
E.db["unitframe"]["colors"]["power"]["MANA"]["b"] = 161 / 255
E.db["unitframe"]["colors"]["power"]["MANA"]["g"] = 115 / 255
E.db["unitframe"]["colors"]["power"]["MANA"]["r"] = 79 / 255
E.db["unitframe"]["colors"]["power"]["FURY"]["r"] = 227 / 255
E.db["unitframe"]["colors"]["power"]["FURY"]["g"] = 126 / 255
E.db["unitframe"]["colors"]["power"]["FURY"]["b"] = 39 / 255
E.db["unitframe"]["colors"]["power"]["FOCUS"]["b"] = 69 / 255
E.db["unitframe"]["colors"]["power"]["FOCUS"]["g"] = 110 / 255
E.db["unitframe"]["colors"]["power"]["FOCUS"]["r"] = 181 / 255
E.db["unitframe"]["colors"]["power"]["RUNIC_POWER"]["r"] = 0 / 255
E.db["unitframe"]["colors"]["power"]["RUNIC_POWER"]["g"] = 209 / 255
E.db["unitframe"]["colors"]["power"]["RUNIC_POWER"]["b"] = 255 / 255
E.db["unitframe"]["colors"]["power"]["ENERGY"]["b"] = 89 / 255
E.db["unitframe"]["colors"]["power"]["ENERGY"]["g"] = 161 / 255
E.db["unitframe"]["colors"]["power"]["ENERGY"]["r"] = 166 / 255
E.db["unitframe"]["colors"]["power"]["MAELSTROM"]["r"] = 0 / 255
E.db["unitframe"]["colors"]["power"]["MAELSTROM"]["g"] = 128 / 255
E.db["unitframe"]["colors"]["power"]["MAELSTROM"]["b"] = 255 / 255
E.db["unitframe"]["colors"]["power"]["PAIN"]["r"] = 225 / 255
E.db["unitframe"]["colors"]["power"]["PAIN"]["g"] = 225 / 255
E.db["unitframe"]["colors"]["power"]["PAIN"]["b"] = 225 / 255
E.db["unitframe"]["colors"]["power"]["LUNAR_POWER"]["b"] = 31 / 255
E.db["unitframe"]["colors"]["power"]["LUNAR_POWER"]["g"] = 219 / 255
E.db["unitframe"]["colors"]["power"]["LUNAR_POWER"]["r"] = 230 / 255
E.db["unitframe"]["colors"]["power"]["INSANITY"]["b"] = 176 / 255
E.db["unitframe"]["colors"]["power"]["INSANITY"]["g"] = 36 / 255
E.db["unitframe"]["colors"]["power"]["INSANITY"]["r"] = 140 / 255
E.db["unitframe"]["colors"]["power"]["RAGE"]["b"] = 64 / 255
E.db["unitframe"]["colors"]["power"]["RAGE"]["g"] = 64 / 255
E.db["unitframe"]["colors"]["power"]["RAGE"]["r"] = 199 / 255
E.db["unitframe"]["colors"]["auraBarDebuff"]["r"] = 79 / 255
E.db["unitframe"]["colors"]["auraBarDebuff"]["g"] = 79 / 255
E.db["unitframe"]["colors"]["auraBarDebuff"]["b"] = 79 / 255
E.db["unitframe"]["colors"]["health"]["r"] = 30 / 255
E.db["unitframe"]["colors"]["health"]["g"] = 30 / 255
E.db["unitframe"]["colors"]["health"]["b"] = 30 / 255
E.db["unitframe"]["colors"]["health_backdrop"]["r"] = 30 / 255
E.db["unitframe"]["colors"]["health_backdrop"]["g"] = 30 / 255
E.db["unitframe"]["colors"]["health_backdrop"]["b"] = 30 / 255
E.db["unitframe"]["colors"]["castColor"]["r"] = 0 / 255
E.db["unitframe"]["colors"]["castColor"]["g"] = 128 / 255
E.db["unitframe"]["colors"]["castColor"]["b"] = 255 / 255
E.db["unitframe"]["colors"]["castNoInterrupt"]["r"] = 200 / 255
E.db["unitframe"]["colors"]["castNoInterrupt"]["g"] = 20 / 255
E.db["unitframe"]["colors"]["castNoInterrupt"]["b"] = 20 / 255
E.db["unitframe"]["colors"]["castbar_backdrop"]["r"] = 30 / 255
E.db["unitframe"]["colors"]["castbar_backdrop"]["g"] = 30 / 255
E.db["unitframe"]["colors"]["castbar_backdrop"]["b"] = 30 / 255
E.db["unitframe"]["colors"]["healthMultiplier"] = 1
E.db["unitframe"]["colors"]["healthclass"] = true
E.db["unitframe"]["colors"]["powerclass"] = false
E.db["unitframe"]["colors"]["classbackdrop"] = false
E.db["unitframe"]["colors"]["colorhealthbyvalue"] = false
E.db["unitframe"]["colors"]["customhealthbackdrop"] = true
E.db["unitframe"]["colors"]["customcastbarbackdrop"] = true
E.db["unitframe"]["colors"]["transparentAurabars"] = true
E.db["unitframe"]["colors"]["transparentCastbar"] = true
E.db["unitframe"]["colors"]["frameGlow"]["targetGlow"]["enable"] = false
E.db["unitframe"]["colors"]["frameGlow"]["mouseoverGlow"]["enable"] = false
E.db["unitframe"]["colors"]["frameGlow"]["mouseoverGlow"]["texture"] = "GennUI Blinkii"
E.db["unitframe"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["fontSize"] = 12
E.db["unitframe"]["smoothbars"] = true
E.db["unitframe"]["statusbar"] = "GennUI Blinkii"
E.db["unitframe"]["smartRaidFilter"] = false

---> UF Custom Texts
E.db["unitframe"]["units"]["player"]["customTexts"] = E.db["unitframe"]["units"]["player"]["customTexts"] or {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"] = {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"] = {}
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"] = E.db["unitframe"]["units"]["target"]["customTexts"] or {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"] = {}
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"] = {}	
E.db["unitframe"]["units"]["party"]["customTexts"] = E.db["unitframe"]["units"]["party"]["customTexts"] or {}
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"] = {}
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"] = {}

---> UF Player
E.db["unitframe"]["units"]["player"]["CombatIcon"]["size"] = 32
E.db["unitframe"]["units"]["player"]["aurabar"]["enable"] = false
E.db["unitframe"]["units"]["player"]["buffs"]["anchorPoint"] = "TOPRIGHT"
E.db["unitframe"]["units"]["player"]["buffs"]["attachTo"] = "FRAME"
E.db["unitframe"]["units"]["player"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["player"]["buffs"]["enable"] = true
E.db["unitframe"]["units"]["player"]["buffs"]["yOffset"] = 14
E.db["unitframe"]["units"]["player"]["castbar"]["iconAttached"] = false
E.db["unitframe"]["units"]["player"]["castbar"]["iconAttachedTo"] = "Castbar"
E.db["unitframe"]["units"]["player"]["castbar"]["iconSize"] = 36
E.db["unitframe"]["units"]["player"]["castbar"]["iconXOffset"] = -2
E.db["unitframe"]["units"]["player"]["castbar"]["width"] = 240
E.db["unitframe"]["units"]["player"]["classbar"]["autoHide"] = true
E.db["unitframe"]["units"]["player"]["classbar"]["fill"] = "spaced"
E.db["unitframe"]["units"]["player"]["classbar"]["height"] = 4
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["size"] = 16
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["text_format"] = "[health:current:shortvalue]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["xOffset"] = 0
E.db["unitframe"]["units"]["player"]["customTexts"]["gHealth"]["yOffset"] = -4
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["size"] = 10
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["text_format"] = "||cff00d1ff[gnuihmana]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["xOffset"] = 0
E.db["unitframe"]["units"]["player"]["customTexts"]["gMana"]["yOffset"] = 6
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["size"] = 16
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["text_format"] = "[name:long]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["xOffset"] = 0
E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["yOffset"] = 24
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["enable"] = true
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["size"] = 10
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["text_format"] = "[powercolor][gnuipower]"
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["xOffset"] = 0
E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["yOffset"] = -6
E.db["unitframe"]["units"]["player"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["player"]["debuffs"]["enable"] = false
E.db["unitframe"]["units"]["player"]["health"]["text_format"] = ""
E.db["unitframe"]["units"]["player"]["height"] = 30
E.db["unitframe"]["units"]["player"]["infoPanel"]["transparent"] = true
E.db["unitframe"]["units"]["player"]["power"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["player"]["power"]["enable"] = false
E.db["unitframe"]["units"]["player"]["power"]["height"] = 4
E.db["unitframe"]["units"]["player"]["power"]["text_format"] = ""
E.db["unitframe"]["units"]["player"]["power"]["width"] = "spaced"
E.db["unitframe"]["units"]["player"]["pvp"]["text_format"] = ""
E.db["unitframe"]["units"]["player"]["raidicon"]["attachTo"] = "CENTER"
E.db["unitframe"]["units"]["player"]["raidicon"]["yOffset"] = 12
E.db["unitframe"]["units"]["player"]["width"] = 220
E.db["unitframe"]["units"]["player"]["threatStyle"] = "NONE"

---> UF Target
E.db["unitframe"]["units"]["target"]["CombatIcon"]["size"] = 32
E.db["unitframe"]["units"]["target"]["aurabar"]["attachTo"] = "BUFFS"
E.db["unitframe"]["units"]["target"]["aurabar"]["height"] = 16
E.db["unitframe"]["units"]["target"]["aurabar"]["maxBars"] = 4
E.db["unitframe"]["units"]["target"]["aurabar"]["priority"] = "Blacklist,blockNoDuration,CCDebuffs,Personal,Boss,RaidDebuffs,PlayerBuffs"
E.db["unitframe"]["units"]["target"]["buffs"]["anchorPoint"] = "TOPLEFT"
E.db["unitframe"]["units"]["target"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["target"]["buffs"]["priority"] = "Blacklist,Dispellable,Personal,nonPersonal"
E.db["unitframe"]["units"]["target"]["buffs"]["yOffset"] = 14
E.db["unitframe"]["units"]["target"]["castbar"]["iconAttached"] = false
E.db["unitframe"]["units"]["target"]["castbar"]["iconAttachedTo"] = "Castbar"
E.db["unitframe"]["units"]["target"]["castbar"]["iconPosition"] = "RIGHT"
E.db["unitframe"]["units"]["target"]["castbar"]["iconSize"] = 36
E.db["unitframe"]["units"]["target"]["castbar"]["iconXOffset"] = 2
E.db["unitframe"]["units"]["target"]["castbar"]["width"] = 240
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["size"] = 16
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["text_format"] = "[health:current:shortvalue]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gHealth"]["yOffset"] = -4
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["justifyH"] = "CENTER"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["size"] = 10
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["text_format"] = "[namecolor][smartclass] ||cffffffff LvL ||r[difficultycolor][level] [classification]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gInfo"]["yOffset"] = -18
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["size"] = 16
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["text_format"] = "[name:abbrev:long]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["yOffset"] = 24
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["size"] = 10
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["text_format"] = "[perhp]%"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gPercent"]["yOffset"] = 8
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["enable"] = true
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["size"] = 10
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["text_format"] = "[powercolor][gnuipower]"
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["xOffset"] = 0
E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["yOffset"] = -6
E.db["unitframe"]["units"]["target"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["target"]["debuffs"]["enable"] = false
E.db["unitframe"]["units"]["target"]["health"]["text_format"] = ""
E.db["unitframe"]["units"]["target"]["height"] = 27
E.db["unitframe"]["units"]["target"]["name"]["text_format"] = ""
E.db["unitframe"]["units"]["target"]["phaseIndicator"]["enable"] = false
E.db["unitframe"]["units"]["target"]["power"]["enable"] = false
E.db["unitframe"]["units"]["target"]["power"]["height"] = 4
E.db["unitframe"]["units"]["target"]["power"]["text_format"] = ""
E.db["unitframe"]["units"]["target"]["power"]["width"] = "spaced"
E.db["unitframe"]["units"]["target"]["raidicon"]["attachTo"] = "CENTER"
E.db["unitframe"]["units"]["target"]["raidicon"]["yOffset"] = 12
E.db["unitframe"]["units"]["target"]["width"] = 220
E.db["unitframe"]["units"]["target"]["threatStyle"] = "NONE"

---> UF Pet
E.db["unitframe"]["units"]["pet"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["pet"]["castbar"]["enable"] = false
E.db["unitframe"]["units"]["pet"]["castbar"]["width"] = 120
E.db["unitframe"]["units"]["pet"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["pet"]["health"]["position"] = "BOTTOMLEFT"
E.db["unitframe"]["units"]["pet"]["health"]["xOffset"] = 0
E.db["unitframe"]["units"]["pet"]["height"] = 27
E.db["unitframe"]["units"]["pet"]["name"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["pet"]["name"]["position"] = "LEFT"
E.db["unitframe"]["units"]["pet"]["name"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["pet"]["name"]["yOffset"] = 20
E.db["unitframe"]["units"]["pet"]["power"]["enable"] = false
E.db["unitframe"]["units"]["pet"]["power"]["height"] = 4
E.db["unitframe"]["units"]["pet"]["power"]["width"] = "spaced"
E.db["unitframe"]["units"]["pet"]["width"] = 120
E.db["unitframe"]["units"]["pet"]["threatStyle"] = "NONE"

---> UF Target's Target
E.db["unitframe"]["units"]["targettarget"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["targettarget"]["buffs"]["perrow"] = 4
E.db["unitframe"]["units"]["targettarget"]["debuffs"]["attachTo"] = "FRAME"
E.db["unitframe"]["units"]["targettarget"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["targettarget"]["debuffs"]["priority"] = "Blacklist,Dispellable,Boss,RaidDebuffs,CCDebuffs,Personal,Whitelist"
E.db["unitframe"]["units"]["targettarget"]["health"]["position"] = "BOTTOMRIGHT"
E.db["unitframe"]["units"]["targettarget"]["health"]["xOffset"] = 0
E.db["unitframe"]["units"]["targettarget"]["height"] = 27
E.db["unitframe"]["units"]["targettarget"]["name"]["attachTextTo"] = "Frame"
E.db["unitframe"]["units"]["targettarget"]["name"]["position"] = "RIGHT"
E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["targettarget"]["name"]["yOffset"] = 20
E.db["unitframe"]["units"]["targettarget"]["power"]["enable"] = false
E.db["unitframe"]["units"]["targettarget"]["power"]["height"] = 4
E.db["unitframe"]["units"]["targettarget"]["power"]["width"] = "spaced"
E.db["unitframe"]["units"]["targettarget"]["raidicon"]["attachTo"] = "CENTER"
E.db["unitframe"]["units"]["targettarget"]["raidicon"]["yOffset"] = 12
E.db["unitframe"]["units"]["targettarget"]["width"] = 120
E.db["unitframe"]["units"]["targettarget"]["threatStyle"] = "NONE"

---> UF Party
E.db["unitframe"]["units"]["party"]["buffs"]["anchorPoint"] = "RIGHT"
E.db["unitframe"]["units"]["party"]["buffs"]["clickThrough"] = true
E.db["unitframe"]["units"]["party"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["party"]["buffs"]["enable"] = true
E.db["unitframe"]["units"]["party"]["buffs"]["perrow"] = 1
E.db["unitframe"]["units"]["party"]["buffs"]["sizeOverride"] = 28
E.db["unitframe"]["units"]["party"]["buffs"]["xOffset"] = -55
E.db["unitframe"]["units"]["party"]["buffs"]["yOffset"] = 15
E.db["unitframe"]["units"]["party"]["castbar"]["width"] = 180
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["enable"] = true
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["justifyH"] = "RIGHT"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["size"] = 10
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["text_format"] = "||cff00d1ff[gnuihmana]"
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["customTexts"]["gMana"]["yOffset"] = 8
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["attachTextTo"] = "Health"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["enable"] = true
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["justifyH"] = "LEFT"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["size"] = 14
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["yOffset"] = 24
E.db["unitframe"]["units"]["party"]["debuffs"]["clickThrough"] = true
E.db["unitframe"]["units"]["party"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["party"]["debuffs"]["perrow"] = 1
E.db["unitframe"]["units"]["party"]["debuffs"]["priority"] = "Blacklist,CCDebuffs,Dispellable,Boss,RaidDebuffs,Whitelist"
E.db["unitframe"]["units"]["party"]["debuffs"]["sizeOverride"] = 42
E.db["unitframe"]["units"]["party"]["debuffs"]["xOffset"] = 2
E.db["unitframe"]["units"]["party"]["healPrediction"]["enable"] = true
E.db["unitframe"]["units"]["party"]["health"]["position"] = "BOTTOMLEFT"
E.db["unitframe"]["units"]["party"]["health"]["text_format"] = "[health:current:shortvalue]"
E.db["unitframe"]["units"]["party"]["health"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["height"] = 35
E.db["unitframe"]["units"]["party"]["name"]["text_format"] = ""
E.db["unitframe"]["units"]["party"]["petsGroup"]["anchorPoint"] = "BOTTOMRIGHT"
E.db["unitframe"]["units"]["party"]["petsGroup"]["enable"] = true
E.db["unitframe"]["units"]["party"]["petsGroup"]["height"] = 10
E.db["unitframe"]["units"]["party"]["petsGroup"]["name"]["text_format"] = ""
E.db["unitframe"]["units"]["party"]["petsGroup"]["xOffset"] = 0
E.db["unitframe"]["units"]["party"]["phaseIndicator"]["enable"] = false
E.db["unitframe"]["units"]["party"]["power"]["displayAltPower"] = true
E.db["unitframe"]["units"]["party"]["power"]["height"] = 4
E.db["unitframe"]["units"]["party"]["power"]["text_format"] = ""
E.db["unitframe"]["units"]["party"]["power"]["width"] = "spaced"
E.db["unitframe"]["units"]["party"]["raidicon"]["attachTo"] = "CENTER"
E.db["unitframe"]["units"]["party"]["raidicon"]["yOffset"] = 12
E.db["unitframe"]["units"]["party"]["rdebuffs"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["party"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["party"]["rdebuffs"]["fontSize"] = 12
E.db["unitframe"]["units"]["party"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["party"]["rdebuffs"]["size"] = 28
E.db["unitframe"]["units"]["party"]["rdebuffs"]["yOffset"] = 3
E.db["unitframe"]["units"]["party"]["roleIcon"]["damager"] = false
E.db["unitframe"]["units"]["party"]["verticalSpacing"] = 20
E.db["unitframe"]["units"]["party"]["width"] = 180
E.db["unitframe"]["units"]["party"]["threatStyle"] = "NONE"

---> UF Raid
E.db["unitframe"]["units"]["raid"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["raid"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["raid"]["health"]["text_format"] = ""
E.db["unitframe"]["units"]["raid"]["height"] = 35
E.db["unitframe"]["units"]["raid"]["horizontalSpacing"] = 1
E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[name:short]"
E.db["unitframe"]["units"]["raid"]["phaseIndicator"]["enable"] = false
E.db["unitframe"]["units"]["raid"]["power"]["displayAltPower"] = true
E.db["unitframe"]["units"]["raid"]["power"]["enable"] = false
E.db["unitframe"]["units"]["raid"]["power"]["height"] = 4
E.db["unitframe"]["units"]["raid"]["power"]["width"] = "spaced"
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["duration"]["color"]["g"] = 0.90196078431373
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["fontSize"] = 12
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["size"] = 28
E.db["unitframe"]["units"]["raid"]["rdebuffs"]["yOffset"] = 3
E.db["unitframe"]["units"]["raid"]["roleIcon"]["damager"] = false
E.db["unitframe"]["units"]["raid"]["verticalSpacing"] = 1
E.db["unitframe"]["units"]["raid"]["threatStyle"] = "NONE"

---> UF Raid40
E.db["unitframe"]["units"]["raid40"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["raid40"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["raid40"]["health"]["text_format"] = ""
E.db["unitframe"]["units"]["raid40"]["height"] = 22
E.db["unitframe"]["units"]["raid40"]["horizontalSpacing"] = 1
E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = "[name:short]"
E.db["unitframe"]["units"]["raid40"]["phaseIndicator"]["enable"] = false
E.db["unitframe"]["units"]["raid40"]["power"]["displayAltPower"] = true
E.db["unitframe"]["units"]["raid40"]["power"]["height"] = 4
E.db["unitframe"]["units"]["raid40"]["power"]["width"] = "spaced"
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["enable"] = true
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["fontSize"] = 12
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["size"] = 22
E.db["unitframe"]["units"]["raid40"]["roleIcon"]["damager"] = false
E.db["unitframe"]["units"]["raid40"]["verticalSpacing"] = 1
E.db["unitframe"]["units"]["raid40"]["threatStyle"] = "NONE"

---> UF Tank
E.db["unitframe"]["units"]["tank"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["tank"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["tank"]["name"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["fontSize"] = 12
E.db["unitframe"]["units"]["tank"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["tank"]["targetsGroup"]["height"] = 20
E.db["unitframe"]["units"]["tank"]["targetsGroup"]["name"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["tank"]["targetsGroup"]["width"] = 80
E.db["unitframe"]["units"]["tank"]["threatStyle"] = "NONE"

---> UF Assist
E.db["unitframe"]["units"]["assist"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["assist"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["assist"]["name"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["assist"]["rdebuffs"]["font"] = "Exo 2 Semi Bold"
E.db["unitframe"]["units"]["assist"]["rdebuffs"]["fontOutline"] = "OUTLINE"
E.db["unitframe"]["units"]["assist"]["rdebuffs"]["fontSize"] = 12
E.db["unitframe"]["units"]["assist"]["rdebuffs"]["onlyMatchSpellID"] = false
E.db["unitframe"]["units"]["assist"]["targetsGroup"]["enable"] = false
E.db["unitframe"]["units"]["assist"]["targetsGroup"]["height"] = 20
E.db["unitframe"]["units"]["assist"]["targetsGroup"]["name"]["text_format"] = "[name:medium]"
E.db["unitframe"]["units"]["assist"]["targetsGroup"]["width"] = 80
E.db["unitframe"]["units"]["assist"]["threatStyle"] = "NONE"

-- DataTexts
E.db["datatexts"]["panels"]["MinimapPanel"][1] = "Guild"
E.db["datatexts"]["panels"]["MinimapPanel"][2] = "Friends"
E.db["datatexts"]["battleground"] = false
E.db["datatexts"]["font"] = "Exo 2 Semi Bold"
E.db["datatexts"]["fontOutline"] = "OUTLINE"
E.db["datatexts"]["fontSize"] = 11
E.db["datatexts"]["panels"]["LeftChatDataPanel"][3] = "System"
E.db["datatexts"]["panels"]["LeftChatDataPanel"]["backdrop"] = false
E.db["datatexts"]["panels"]["MinimapPanel"]["backdrop"] = false
E.db["datatexts"]["panels"]["RightChatDataPanel"][1] = "Date"
E.db["datatexts"]["panels"]["RightChatDataPanel"]["backdrop"] = false

-- ActionBars
E.db["actionbar"]["bar1"]["enabled"] = true
E.db["actionbar"]["bar1"]["buttonSize"] = 36
E.db["actionbar"]["bar1"]["buttonSpacing"] = 1
E.db["actionbar"]["bar1"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar1"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar1"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar1"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar1"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar1"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar1"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar1"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar1"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar1"]["macrotext"] = true
E.db["actionbar"]["bar10"]["enabled"] = false
E.db["actionbar"]["bar10"]["buttonSpacing"] = 1
E.db["actionbar"]["bar10"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar10"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar10"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar10"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar10"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar10"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar10"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar10"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar10"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar10"]["macrotext"] = true
E.db["actionbar"]["bar2"]["enabled"] = true
E.db["actionbar"]["bar2"]["buttonSize"] = 36
E.db["actionbar"]["bar2"]["buttonSpacing"] = 1
E.db["actionbar"]["bar2"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar2"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar2"]["enabled"] = true
E.db["actionbar"]["bar2"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar2"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar2"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar2"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar2"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar2"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar2"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar2"]["macrotext"] = true
E.db["actionbar"]["bar3"]["enabled"] = true
E.db["actionbar"]["bar3"]["buttonSpacing"] = 1
E.db["actionbar"]["bar3"]["buttons"] = 12
E.db["actionbar"]["bar3"]["buttonsPerRow"] = 6
E.db["actionbar"]["bar3"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar3"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar3"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar3"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar3"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar3"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar3"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar3"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar3"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar3"]["macrotext"] = true
E.db["actionbar"]["bar4"]["enabled"] = true
E.db["actionbar"]["bar4"]["backdrop"] = false
E.db["actionbar"]["bar4"]["buttonSize"] = 28
E.db["actionbar"]["bar4"]["buttonSpacing"] = 1
E.db["actionbar"]["bar4"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar4"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar4"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar4"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar4"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar4"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar4"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar4"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar4"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar4"]["macrotext"] = true
E.db["actionbar"]["bar4"]["mouseover"] = true
E.db["actionbar"]["bar5"]["enabled"] = true
E.db["actionbar"]["bar5"]["buttonSpacing"] = 1
E.db["actionbar"]["bar5"]["buttons"] = 12
E.db["actionbar"]["bar5"]["buttonsPerRow"] = 6
E.db["actionbar"]["bar5"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar5"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar5"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar5"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar5"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar5"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar5"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar5"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar5"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar5"]["macrotext"] = true
E.db["actionbar"]["bar6"]["enabled"] = false
E.db["actionbar"]["bar6"]["buttonSpacing"] = 1
E.db["actionbar"]["bar6"]["buttons"] = 12
E.db["actionbar"]["bar6"]["buttonsPerRow"] = 6
E.db["actionbar"]["bar6"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar6"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar6"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar6"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar6"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar6"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar6"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar6"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar6"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar6"]["macrotext"] = true
E.db["actionbar"]["bar7"]["enabled"] = false
E.db["actionbar"]["bar7"]["buttonSpacing"] = 1
E.db["actionbar"]["bar7"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar7"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar7"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar7"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar7"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar7"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar7"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar7"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar7"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar7"]["macrotext"] = true
E.db["actionbar"]["bar8"]["enabled"] = false
E.db["actionbar"]["bar8"]["buttonSpacing"] = 1
E.db["actionbar"]["bar8"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar8"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar8"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar8"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar8"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar8"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar8"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar8"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar8"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar8"]["macrotext"] = true
E.db["actionbar"]["bar9"]["enabled"] = false
E.db["actionbar"]["bar9"]["buttonSpacing"] = 1
E.db["actionbar"]["bar9"]["countFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar9"]["countFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar9"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar9"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar9"]["macroFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["bar9"]["macroFontOutline"] = "OUTLINE"
E.db["actionbar"]["bar9"]["macroTextPosition"] = "BOTTOM"
E.db["actionbar"]["bar9"]["macroTextXOffset"] = 2
E.db["actionbar"]["bar9"]["macroTextYOffset"] = 3
E.db["actionbar"]["bar9"]["macrotext"] = true
E.db["actionbar"]["barPet"]["backdrop"] = false
E.db["actionbar"]["barPet"]["backdropSpacing"] = 1
E.db["actionbar"]["barPet"]["buttonSize"] = 21
E.db["actionbar"]["barPet"]["buttonSpacing"] = 1
E.db["actionbar"]["barPet"]["buttonsPerRow"] = 10
E.db["actionbar"]["barPet"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["barPet"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["font"] = "Exo 2 Semi Bold"
E.db["actionbar"]["fontOutline"] = "OUTLINE"
E.db["actionbar"]["fontSize"] = 11
E.db["actionbar"]["microbar"]["buttonHeight"] = 26
E.db["actionbar"]["microbar"]["buttonSpacing"] = 1
E.db["actionbar"]["microbar"]["enabled"] = true
E.db["actionbar"]["microbar"]["mouseover"] = true
E.db["actionbar"]["stanceBar"]["buttonSize"] = 26
E.db["actionbar"]["stanceBar"]["buttonSpacing"] = 1
E.db["actionbar"]["stanceBar"]["hotkeyFont"] = "Exo 2 Semi Bold"
E.db["actionbar"]["stanceBar"]["hotkeyFontOutline"] = "OUTLINE"
E.db["actionbar"]["stanceBar"]["mouseover"] = true
E.db["actionbar"]["useRangeColorText"] = true
E.db["actionbar"]["vehicleExitButton"]["size"] = 40

-- NamePlates
E.private["nameplates"]["enable"] = true
E.db["nameplates"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["plateSize"]["enemyWidth"] = 200
E.db["nameplates"]["plateSize"]["friendlyWidth"] = 200
E.db["nameplates"]["plateSize"]["personalWidth"] = 200
E.db["nameplates"]["smoothbars"] = true
E.db["nameplates"]["statusbar"] = "GennUI Blinkii"
E.db["nameplates"]["fadeIn"] = true

--> NP Colors
E.db["nameplates"]["colors"]["castColor"]["b"] = 255 / 255
E.db["nameplates"]["colors"]["castColor"]["g"] = 128 / 255
E.db["nameplates"]["colors"]["castColor"]["r"] = 0 / 255
E.db["nameplates"]["colors"]["castNoInterruptColor"]["b"] = 30 / 255
E.db["nameplates"]["colors"]["castNoInterruptColor"]["g"] = 30 / 255
E.db["nameplates"]["colors"]["castNoInterruptColor"]["r"] = 30 / 255
E.db["nameplates"]["colors"]["classResources"]["DEATHKNIGHT"]["a"] = 1
E.db["nameplates"]["colors"]["classResources"]["DEATHKNIGHT"]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["DEATHKNIGHT"]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["DEATHKNIGHT"]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["WARLOCK"]["a"] = 1
E.db["nameplates"]["colors"]["classResources"]["WARLOCK"]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["WARLOCK"]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["WARLOCK"]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["PALADIN"]["a"] = 1
E.db["nameplates"]["colors"]["classResources"]["PALADIN"]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["PALADIN"]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["PALADIN"]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MAGE"]["a"] = 1
E.db["nameplates"]["colors"]["classResources"]["MAGE"]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MAGE"]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MAGE"]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][1]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][1]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][1]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][2]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][2]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][2]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][3]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][3]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][3]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][4]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][4]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][4]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][5]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][5]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][5]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][6]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][6]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["comboPoints"][6]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][1]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][1]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][1]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][2]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][2]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][2]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][3]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][3]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][3]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][4]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][4]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][4]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][5]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][5]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][5]["b"] = classColor.b
E.db["nameplates"]["colors"]["classResources"]["MONK"][6]["r"] = classColor.r
E.db["nameplates"]["colors"]["classResources"]["MONK"][6]["g"] = classColor.g
E.db["nameplates"]["colors"]["classResources"]["MONK"][6]["b"] = classColor.b

---> NP Units
----> Enemy NPC
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["maxDuration"] = 300
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["priority"] = "Blacklist,Dispellable,RaidBuffsElvUI,PlayerBuffs,TurtleBuffs,CastByUnit"
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["xOffset"] = -2
E.db["nameplates"]["units"]["ENEMY_NPC"]["buffs"]["yOffset"] = 33
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["enable"] = false
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconOffsetX"] = 2
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconOffsetY"] = -2
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["iconSize"] = 36
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["sourceInterruptClassColor"] = false
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["width"] = 200
E.db["nameplates"]["units"]["ENEMY_NPC"]["castbar"]["yOffset"] = -15
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["priority"] = "Blacklist,CCDebuffs,Personal"
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["ENEMY_NPC"]["debuffs"]["yOffset"] = 5
E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["height"] = 16
E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["health"]["text"]["format"] = "[health:current:shortvalue]"
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["format"] = "[difficultycolor][level]"
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["parent"] = "Health"
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["position"] = "BOTTOMRIGHT"
E.db["nameplates"]["units"]["ENEMY_NPC"]["level"]["yOffset"] = 14
E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["format"] = "[namecolor][name:abbrev:long]"
E.db["nameplates"]["units"]["ENEMY_NPC"]["name"]["yOffset"] = -5
E.db["nameplates"]["units"]["ENEMY_NPC"]["portrait"]["height"] = 36
E.db["nameplates"]["units"]["ENEMY_NPC"]["portrait"]["width"] = 36
E.db["nameplates"]["units"]["ENEMY_NPC"]["portrait"]["yOffset"] = 0
E.db["nameplates"]["units"]["ENEMY_NPC"]["power"]["height"] = 4
E.db["nameplates"]["units"]["ENEMY_NPC"]["power"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["power"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["power"]["width"] = 200
E.db["nameplates"]["units"]["ENEMY_NPC"]["power"]["yOffset"] = -14
E.db["nameplates"]["units"]["ENEMY_NPC"]["questIcon"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["questIcon"]["size"] = 24
E.db["nameplates"]["units"]["ENEMY_NPC"]["questIcon"]["xOffset"] = 14
E.db["nameplates"]["units"]["ENEMY_NPC"]["raidTargetIndicator"]["xOffset"] = 26
E.db["nameplates"]["units"]["ENEMY_NPC"]["title"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_NPC"]["title"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_NPC"]["title"]["format"] = "[guild:brackets]"
----> Target
E.db["nameplates"]["units"]["TARGET"]["classpower"]["height"] = 6
E.db["nameplates"]["units"]["TARGET"]["classpower"]["width"] = 60
E.db["nameplates"]["units"]["TARGET"]["classpower"]["yOffset"] = -12
E.db["nameplates"]["units"]["TARGET"]["arrow"] = "ArrowUp"
E.db["nameplates"]["units"]["TARGET"]["classpower"]["classColor"] = true
E.db["nameplates"]["units"]["TARGET"]["classpower"]["height"] = 4
E.db["nameplates"]["units"]["TARGET"]["classpower"]["width"] = 110
E.db["nameplates"]["units"]["TARGET"]["glowStyle"] = "style4"
----> Friendly NPC
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["maxDuration"] = 300
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["xOffset"] = -2
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["buffs"]["yOffset"] = 33
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["enable"] = false
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["iconOffsetX"] = 2
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["iconOffsetY"] = -2
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["iconSize"] = 36
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["sourceInterruptClassColor"] = false
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["width"] = 200
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["castbar"]["yOffset"] = -15
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["debuffs"]["yOffset"] = 5
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["height"] = 16
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["health"]["text"]["format"] = "[health:current:shortvalue]"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["format"] = "[difficultycolor][level]"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["parent"] = "Health"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["position"] = "BOTTOMRIGHT"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["level"]["yOffset"] = 14
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["format"] = "[namecolor][name:abbrev:long]"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["name"]["yOffset"] = -5
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["nameOnly"] = false
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["portrait"]["height"] = 36
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["portrait"]["width"] = 36
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["power"]["height"] = 4
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["power"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["power"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["power"]["width"] = 200
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["power"]["yOffset"] = -14
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["questIcon"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["questIcon"]["size"] = 24
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["questIcon"]["xOffset"] = 14
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["raidTargetIndicator"]["xOffset"] = 26
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["title"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["title"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_NPC"]["title"]["format"] = "[guild:brackets]"
----> Friendly Player
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["maxDuration"] = 300
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["priority"] = "Blacklist,TurtleBuffs,Personal,blockNoDuration"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["xOffset"] = -2
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["buffs"]["yOffset"] = 33
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["enable"] = false
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["iconOffsetX"] = 2
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["iconOffsetY"] = -2
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["iconSize"] = 36
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["sourceInterruptClassColor"] = false
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["width"] = 200
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["castbar"]["yOffset"] = -15
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["priority"] = "Blacklist,Dispellable,CCDebuffs,Personal,Boss,blockNoDuration"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["debuffs"]["yOffset"] = 5
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["height"] = 16
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["health"]["text"]["format"] = "[health:current:shortvalue]"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["parent"] = "Health"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["position"] = "BOTTOMRIGHT"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["level"]["yOffset"] = 14
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["format"] = "[namecolor][name:abbrev:long]"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["name"]["yOffset"] = -5
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["portrait"]["height"] = 36
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["portrait"]["width"] = 36
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["power"]["height"] = 4
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["power"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["power"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["power"]["width"] = 200
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["power"]["yOffset"] = -14
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["raidTargetIndicator"]["xOffset"] = 26
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["title"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["FRIENDLY_PLAYER"]["title"]["fontSize"] = 12
----> Enemy Player
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["priority"] = "Blacklist,Dispellable,TurtleBuffs,PlayerBuffs"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["xOffset"] = -2
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["buffs"]["yOffset"] = 33
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["enable"] = false
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["iconOffsetX"] = 2
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["iconOffsetY"] = -2
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["iconSize"] = 36
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["sourceInterruptClassColor"] = false
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["width"] = 200
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["castbar"]["yOffset"] = -15
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["priority"] = "Blacklist,blockNoDuration,CCDebuffs,Personal,Boss,RaidDebuffs"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["debuffs"]["yOffset"] = 5
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["height"] = 16
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["health"]["text"]["format"] = "[health:current:shortvalue]"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["parent"] = "Health"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["position"] = "BOTTOMRIGHT"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["level"]["yOffset"] = 14
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["name"]["yOffset"] = -5
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["portrait"]["height"] = 36
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["portrait"]["width"] = 36
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["power"]["height"] = 4
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["power"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["power"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["power"]["width"] = 200
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["power"]["yOffset"] = -14
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["raidTargetIndicator"]["xOffset"] = 26
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["title"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["ENEMY_PLAYER"]["title"]["fontSize"] = 12
----> Player
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["size"] = 28
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["xOffset"] = -2
E.db["nameplates"]["units"]["PLAYER"]["buffs"]["yOffset"] = 33
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["enable"] = false
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["fontSize"] = 12
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["iconOffsetX"] = 2
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["iconOffsetY"] = -2
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["iconSize"] = 36
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["sourceInterruptClassColor"] = false
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["width"] = 200
E.db["nameplates"]["units"]["PLAYER"]["castbar"]["yOffset"] = -15
E.db["nameplates"]["units"]["PLAYER"]["classpower"]["enable"] = false
E.db["nameplates"]["units"]["PLAYER"]["classpower"]["height"] = 4
E.db["nameplates"]["units"]["PLAYER"]["classpower"]["width"] = 110
E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["countFont"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["countFontSize"] = 10
E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["numAuras"] = 7
E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["size"] = 28
E.db["nameplates"]["units"]["PLAYER"]["debuffs"]["yOffset"] = 5
E.db["nameplates"]["units"]["PLAYER"]["health"]["height"] = 16
E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["fontSize"] = 14
E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["format"] = "[health:current:shortvalue]"
E.db["nameplates"]["units"]["PLAYER"]["health"]["text"]["yOffset"] = -6
E.db["nameplates"]["units"]["PLAYER"]["level"]["enable"] = true
E.db["nameplates"]["units"]["PLAYER"]["level"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["PLAYER"]["level"]["fontSize"] = 12
E.db["nameplates"]["units"]["PLAYER"]["level"]["parent"] = "Health"
E.db["nameplates"]["units"]["PLAYER"]["level"]["position"] = "BOTTOMRIGHT"
E.db["nameplates"]["units"]["PLAYER"]["level"]["yOffset"] = 14
E.db["nameplates"]["units"]["PLAYER"]["name"]["enable"] = true
E.db["nameplates"]["units"]["PLAYER"]["name"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["PLAYER"]["name"]["fontSize"] = 12
E.db["nameplates"]["units"]["PLAYER"]["name"]["yOffset"] = -5
E.db["nameplates"]["units"]["PLAYER"]["portrait"]["height"] = 36
E.db["nameplates"]["units"]["PLAYER"]["portrait"]["width"] = 36
E.db["nameplates"]["units"]["PLAYER"]["power"]["enable"] = false
E.db["nameplates"]["units"]["PLAYER"]["power"]["height"] = 4
E.db["nameplates"]["units"]["PLAYER"]["power"]["text"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["PLAYER"]["power"]["text"]["fontSize"] = 12
E.db["nameplates"]["units"]["PLAYER"]["power"]["width"] = 200
E.db["nameplates"]["units"]["PLAYER"]["power"]["yOffset"] = -14
E.db["nameplates"]["units"]["PLAYER"]["title"]["font"] = "Exo 2 Semi Bold"
E.db["nameplates"]["units"]["PLAYER"]["title"]["fontSize"] = 12

--> NP Filters
E.db["nameplates"]["filters"]["ElvUI_Target"]["triggers"]["enable"] = false
E.db["nameplates"]["filters"]["ElvUI_NonTarget"]["triggers"]["enable"] = false

---> Custom NP Filters
	for _, filterName in pairs({'Podtender', 'Totems'}) do
		E.global["nameplate"]["filters"][filterName] = {}
		E.NamePlates:StyleFilterCopyDefaults(E.global["nameplate"]["filters"][filterName])
		E.db["nameplates"]["filters"][filterName] = { triggers = { enable = true } }
	end

E.global["nameplate"]["filters"]["Podtender"]["actions"]["color"]["health"] = true
E.global["nameplate"]["filters"]["Podtender"]["actions"]["color"]["healthColor"]["r"] = 0
E.global["nameplate"]["filters"]["Podtender"]["actions"]["scale"] = 1.15
E.global["nameplate"]["filters"]["Podtender"]["actions"]["usePortrait"] = true
E.global["nameplate"]["filters"]["Podtender"]["triggers"]["names"]["164589"] = true
E.global["nameplate"]["filters"]["Podtender"]["triggers"]["priority"] = 2
E.global["nameplate"]["filters"]["Totems"]["actions"]["color"]["health"] = true
E.global["nameplate"]["filters"]["Totems"]["actions"]["color"]["healthColor"]["r"] = 0
E.global["nameplate"]["filters"]["Totems"]["actions"]["scale"] = 1.15
E.global["nameplate"]["filters"]["Totems"]["actions"]["usePortrait"] = true
E.global["nameplate"]["filters"]["Totems"]["triggers"]["nameplateType"]["enable"] = true
E.global["nameplate"]["filters"]["Totems"]["triggers"]["nameplateType"]["enemyNPC"] = true
E.global["nameplate"]["filters"]["Totems"]["triggers"]["nameplateType"]["enemyPlayer"] = true
E.global["nameplate"]["filters"]["Totems"]["triggers"]["names"]["105427"] = true
E.global["nameplate"]["filters"]["Totems"]["triggers"]["names"]["105451"] = true
E.global["nameplate"]["filters"]["Totems"]["triggers"]["names"]["59764"] = true
E.global["nameplate"]["filters"]["Totems"]["triggers"]["names"]["6112"] = true
E.global["nameplate"]["filters"]["Totems"]["triggers"]["priority"] = 2

-- General
E.db["general"]["valuecolor"]["r"] = classColor.r
E.db["general"]["valuecolor"]["g"] = classColor.g
E.db["general"]["valuecolor"]["b"] = classColor.b
E.db["general"]["altPowerBar"]["statusBarColor"]["b"] = classColor.b
E.db["general"]["altPowerBar"]["statusBarColor"]["g"] = classColor.g
E.db["general"]["altPowerBar"]["statusBarColor"]["r"] = classColor.r
E.db["general"]["altPowerBar"]["font"] = "Exo 2 Semi Bold"
E.db["general"]["altPowerBar"]["smoothbars"] = true
E.db["general"]["altPowerBar"]["statusBar"] = "GennUI Blinkii"
E.db["general"]["autoRepair"] = "GUILD"
E.db["general"]["autoTrackReputation"] = true
E.db["general"]["bottomPanel"] = false
E.db["general"]["font"] = "Exo 2 Semi Bold"
E.db["general"]["fontSize"] = 11
E.db["general"]["interruptAnnounce"] = "SAY"
E.db["general"]["itemLevel"]["itemLevelFont"] = "Exo 2 Semi Bold"
E.db["general"]["itemLevel"]["itemLevelFontSize"] = 10
E.db["general"]["minimap"]["locationFont"] = "Exo 2 Semi Bold"
E.db["general"]["minimap"]["locationText"] = "SHOW"
E.db["general"]["minimap"]["size"] = 150
E.db["general"]["talkingHeadFrameScale"] = 0.75

-- Private
E.private["general"]["chatBubbleFont"] = "Exo 2 Semi Bold"
E.private["general"]["chatBubbleFontOutline"] = "OUTLINE"
E.private["general"]["chatBubbleFontSize"] = 12
E.private["general"]["dmgfont"] = "Exo 2 Semi Bold"
E.private["general"]["glossTex"] = "GennUI Blinkii"
E.private["general"]["namefont"] = "Exo 2 Semi Bold"
E.private["general"]["normTex"] = "GennUI Blinkii"

-- Global
E.global["datatexts"]["settings"]["Friends"]["hideApp"] = true
E.global["datatexts"]["settings"]["Friends"]["hideBSAp"] = true
E.global["datatexts"]["settings"]["Friends"]["hideD3"] = true
E.global["datatexts"]["settings"]["Friends"]["hideHero"] = true
E.global["datatexts"]["settings"]["Friends"]["hidePro"] = true
E.global["datatexts"]["settings"]["Friends"]["hideS1"] = true
E.global["datatexts"]["settings"]["Friends"]["hideS2"] = true
E.global["datatexts"]["settings"]["Friends"]["hideVIPR"] = true
E.global["datatexts"]["settings"]["Friends"]["hideWTCG"] = true
E.global["datatexts"]["settings"]["Gold"]["goldCoins"] = false
E.global["datatexts"]["settings"]["Gold"]["goldFormat"] = "BLIZZARD"
E.global["general"]["commandBarSetting"] = "DISABLED"
E.global["uiScaleInformed"] = true
E.global["general"]["UIScale"] = 0.64

-- ProjectAzilroka Config
if IsAddOnLoaded('ProjectAzilroka') then
E.db["movers"]["SquareMinimapButtonBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-179"
GNUI:LoadPAProfile()
end

-- Update ElvUI
	E:StaggeredUpdateAll(nil, true)
	E:Print(L["|cffc31f3bGennUI |cfffffffflayout has been set"])
	PluginInstallStepComplete.message = "GennUI Layout has been set"
	PluginInstallStepComplete:Show()
end

--[[ Theme Settings ]]--
function GNUI:SetupTheme(theme)
if theme == "dark" then
	E.db["unitframe"]["colors"]["healthclass"] = false
	E.db["unitframe"]["colors"]["powerclass"] = true
	E.db["unitframe"]["colors"]["classbackdrop"] = true
	E.db["unitframe"]["colors"]["customhealthbackdrop"] = false
	E.db["unitframe"]["colors"]["colorhealthbyvalue"] = false
	E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["text_format"] = "[namecolor][name:long]"
	E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["text_format"] = "[namecolor][gnuipower]"
	E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["text_format"] = "[namecolor][name:abbrev:long]"
	E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["text_format"] = "[namecolor][gnuipower]"
	E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = "[namecolor][name:medium]"
	E.db["unitframe"]["units"]["pet"]["name"]["text_format"] = "[namecolor][name:medium]"
	E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["text_format"] = "[namecolor][name:medium]"
	E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[namecolor][name:short]"
	E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = "[namecolor][name:short]"
	E.db["unitframe"]["units"]["tank"]["name"]["text_format"] = "[namecolor][name:medium]"
	E.db["unitframe"]["units"]["assist"]["name"]["text_format"] ="[namecolor][name:medium]"
	elseif theme == "class" then
	E.db["unitframe"]["colors"]["healthclass"] = true
	E.db["unitframe"]["colors"]["powerclass"] = false
	E.db["unitframe"]["colors"]["classbackdrop"] = false
	E.db["unitframe"]["colors"]["customhealthbackdrop"] = true
	E.db["unitframe"]["colors"]["colorhealthbyvalue"] = false
	E.db["unitframe"]["units"]["player"]["customTexts"]["gName"]["text_format"] = "[name:long]"
	E.db["unitframe"]["units"]["player"]["customTexts"]["gPower"]["text_format"] = "[powercolor][gnuipower]"
	E.db["unitframe"]["units"]["target"]["customTexts"]["gName"]["text_format"] = "[name:abbrev:long]"
	E.db["unitframe"]["units"]["target"]["customTexts"]["gPower"]["text_format"] = "[powercolor][gnuipower]"
	E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = "[name:medium]"
	E.db["unitframe"]["units"]["pet"]["name"]["text_format"] = "[name:medium]"
	E.db["unitframe"]["units"]["party"]["customTexts"]["gName"]["text_format"] = "[name:medium]"
	E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[name:short]"
	E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = "[name:short]"
	E.db["unitframe"]["units"]["tank"]["name"]["text_format"] = "[name:medium]"
	E.db["unitframe"]["units"]["assist"]["name"]["text_format"] = "[name:medium]"	
end
	
--Update ElvUI
	E:StaggeredUpdateAll(nil, true)
	E:Print(L["|cffc31f3bGennUI |cfffffffftheme has been set"])
	PluginInstallStepComplete.message = "Theme has been set"
	PluginInstallStepComplete:Show()
end

--[[ Addons Profiles ]]--
function GNUI:SetupAddons(addon)
	
	-- AddOnSkins
	if IsAddOnLoaded('AddOnSkins') then
		GNUI:LoadASProfile()
		E:Print(L["'AddOnSkins' profile has been set."])
	end
	
	-- Ability Team Tracker
	if IsAddOnLoaded('ATT') then
		GNUI:LoadATTProfile()
		E:Print(L["'Ability Team Tracker' profile has been set."])
	end
	
	-- BigWigs
	if IsAddOnLoaded('BigWigs') then
		GNUI:LoadBWProfile()
		E:Print(L["'BigWigs'"])
	end
	
	-- Capping
	if IsAddOnLoaded('Capping') then
		GNUI:LoadCappingProfile()
		E:Print(L["'Capping' profile has been set."])
	end
	
	-- Deadly Boss Mods
	if IsAddOnLoaded('DBM-Core') then
		GNUI:LoadDBMProfile()
		E:Print(L["'DBM' profile has been set."])
	end
	
	-- Details
	if IsAddOnLoaded('Details') then
		GNUI:LoadDetailsProfile()
		E:Print(L["'Details' profile has been set."])
	end
	
	-- Diminish
	if IsAddOnLoaded('Diminish') then
		GNUI:LoadDiminishProfile()
		E:Print(L["'Diminish' profile has been set."])
	end
	
	-- Mik's Scrolling Battle Text
	if IsAddOnLoaded('MikScrollingBattleText') then
		GNUI:LoadMSBTProfile()
		E:Print(L["'MSBT' profile has been set."])
	end

	-- NamePlateCooldowns
	if IsAddOnLoaded('NameplateCooldowns') then
		GNUI:LoadNCProfile()
		E:Print(L["'NameplateCooldowns' profile has been set."])
	end
	
	-- OmniBar
	if IsAddOnLoaded('OmniBar') then
		GNUI:LoadOmniBarProfile()
		E:Print(L["'OmniBar' profile has been set."])
	end
	
	-- Plater
	if IsAddOnLoaded('Plater') then
		E.private["nameplates"]["enable"] = false
		GNUI:LoadPlaterProfile()
		E:Print(L["'Plater' profile has been set. Note: ElvUI NamePlates have been disabled"])
	end
	
	PluginInstallStepComplete.message = "Addons Profiles have been set"
	PluginInstallStepComplete:Show()
end